@@ -33,7 +33,7 @@ class SendDataController:
                         pass
                 copiedProcessedCoTObject = copy.deepcopy(processedCoT)
                 copiedProcessedCoTObject.idData = copiedProcessedCoTObject.idData.encode()
-                shareDataPipe.send([copiedProcessedCoTObject])
+                shareDataPipe.put([copiedProcessedCoTObject])
                 return 1
             elif processedCoT.type == 'other':
                 self.returnData = self.send_to_specific_client(clientInformationQueue, processedCoT, sender, shareDataPipe)
@@ -43,7 +43,7 @@ class SendDataController:
                 return self.returnData
         except Exception as e:
             logger.error(loggingConstants.SENDDATACONTROLLERSENDDATAINQUEUEERROR+str(e))
-            return -1
+            return Exception(e)
 
     def send_to_specific_client(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
@@ -73,7 +73,7 @@ class SendDataController:
                         return -1
                 if shareDataPipe != None:
                     processedCoT.clientInformation = None
-                    shareDataPipe.send(processedCoT)
+                    shareDataPipe.put(processedCoT)
                 else:
                     pass
                 return 1
@@ -83,26 +83,34 @@ class SendDataController:
     def send_to_all(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
             for client in clientInformationQueue:
-    
+
                 sock = client.socket
                 try:
                     if hasattr(processedCoT, 'xmlString'):
                         # print('sending to all ' + str(processedCoT.xmlString))
-                        sock.send(processedCoT.xmlString)
+                        try:
+                            sock.send(processedCoT.xmlString)
+                        except TypeError:
+                            sock.send(processedCoT.xmlString.encode())
                     else:
-                        sock.send(processedCoT.idData)
+                        try:
+                            sock.send(processedCoT.idData)
+                        except TypeError:
+                            sock.send(processedCoT.idData.encode())
                 except Exception as e:
-                    print(e)
-                    logger.error('error in sending of data ' + str(processedCoT.xmlString))
+                    logger.error('error in sending of data ' + str(e))
                     return (-1, client)
             if shareDataPipe != None:
                 processedCoT.clientInformation = None
-                shareDataPipe.send(processedCoT)
+                shareDataPipe.put(processedCoT)
             else:
                 pass
             return 1
         except Exception as e:
-            logger.error('error in send to all ' + str(e))
+            import traceback
+
+            logger.error('error in send to all ' + str(e)+str(traceback.format_exc()))
+            raise Exception(e)
     def geochat_sending(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
             if processedCoT.modelObject.detail._chat.chatgrp.uid1 == 'All Chat Rooms':
@@ -127,7 +135,7 @@ class SendDataController:
                         return -1
                 if shareDataPipe != None:
                     processedCoT.clientInformation = None
-                    shareDataPipe.send(processedCoT)
+                    shareDataPipe.put(processedCoT)
                 else:
                     pass
                 return 1
