@@ -1,6 +1,6 @@
 from defusedxml import ElementTree as etree
 from FreeTAKServer.model.SpecificCoT.SendOther import SendOther
-from .SendCoTAbstractController import SendCoTAbstractController
+from FreeTAKServer.controllers.SpecificCoTControllers.SendCoTAbstractController import SendCoTAbstractController
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
 
@@ -33,21 +33,26 @@ class SendOtherController(SendCoTAbstractController):
     #this function modifies the CoT so only the marti and point tags are present
     def filter_CoT(self, event):
         try:
-            from lxml.etree import SubElement
+            from xml.etree.ElementTree import Element
             outputEvent = etree.fromstring(event)
             tempDetail = outputEvent.find('detail')
             outputEvent.remove(tempDetail)
             detail = etree.fromstring(event).find('detail')
             try:
                 marti = detail.find('marti')
-                outputDetail = SubElement(outputEvent, 'detail')
+                outputDetail = Element('detail')
                 outputDetail.append(marti)
+                outputEvent.append(outputDetail)
                 print('dest client found')
                 self.object.martiPresent = True
-            except:
-                SubElement(outputEvent, 'detail')
+            except Exception as e:
+                outputDetail = Element('detail')
+                outputEvent.append(outputDetail)
                 print('no dest client found')
 
             return outputEvent
         except Exception as e:
-            print('exception filtering CoT ' + str(e))
\ No newline at end of file
+            print('exception filtering CoT ' + str(e))
+            
+if __name__ == '__main__':
+    SendOtherController().filter_CoT(b'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><event how="m-g" stale="2021-04-07T10:55:27Z" start="2021-04-07T10:54:27Z" time="2021-04-07T10:54:27Z" type="a-h-G-E-V-C" uid="RMA1107" version="2.0"><point ce="10" hae="0" lat="0" le="10" lon="0" /><detail><remarks>Device Moving: false Last Comm: 2020-10-17 07:00:49 Last GPS Fix: 2020-10-17 06:38:36</remarks><track course="338" speed="0.0" /><uid Droid="RMA1107" /><status battery="1" /></detail></event>')
\ No newline at end of file
